#ifndef LEVADJ_SRC_HAMDISTBOUNDED_H_
#define LEVADJ_SRC_HAMDISTBOUNDED_H_

int hamDistBounded(const std::string &a,
                   const std::string &b,
                   const int& k) ;

#endif /* LEVADJ_SRC_HAMDISTBOUNDED_H_ */
